
# Slot: types


data types used in the model

URI: [linkml:types](https://w3id.org/linkml/types)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
